@@ -48,7 +48,7 @@ our @EXPORT = qw(
 	
 );
 
-$Text::Reflow::VERSION = "1.08";
+$Text::Reflow::VERSION = "1.10";
 
 bootstrap Text::Reflow $Text::Reflow::VERSION;
 
@@ -193,7 +193,7 @@ Pvt => 1, Cpl => 1, Sgt => 1, Ens => 1, Lieut => 1, Capt => 1, Cmdr => 1,
 Maj => 1, Col => 1, Gen => 1, Adm => 1,
 Dr => 1, Hon => 1, Mlle => 1, Mme => 1, Mr => 1, Mrs => 1, Miss => 1,
 Prof => 1, Rev => 1,
-Bart => 2, Esq => 2,
+Bart => 2, Esq => 2, etc => 2,
 No => 1, St => 1,
 Ave => 2, Rd => 2, Blvd => 2, Ct => 2, Cir => 2,
 A => 1, B => 1, C => 1, D => 1, E => 1, F => 1, G => 1, H => 1,
@@ -557,7 +557,7 @@ sub reflow_penalties {
     $extra[$j] = 0;
   }
   for ($j = 0; $j < $wordcount; $j++) {
-    if ($words[$j] =~ /^(\w+)["')]*([\.\:])["')]*$/) {	# Period or colon
+    if ($words[$j] =~ /^([A-Za-z0-9-]+)["')]*([\.\:])["')]*$/) {	# Period or colon
       if (!defined($abbrev{$1}) || ($2 eq ":")) {	# End of sentence
 	$extra[$j] += $sentence / 2;
 	$extra[$j-1] -= $sentence if ($j > 0);
